@@ -32,7 +32,6 @@
 #include "ephy-encodings.h"
 #include "ephy-file-helpers.h"
 #include "ephy-filters-manager.h"
-#include "ephy-flatpak-utils.h"
 #include "ephy-history-service.h"
 #include "ephy-profile-utils.h"
 #include "ephy-settings.h"
@@ -42,6 +41,7 @@
 #include "ephy-web-app-utils.h"
 #include "ephy-web-extension-proxy.h"
 
+#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <stdlib.h>
@@ -57,6 +57,7 @@
 typedef struct {
   WebKitWebContext *web_context;
   EphyHistoryService *global_history_service;
+  EphyGSBService *global_gsb_service;
   EphyEncodings *encodings;
   GtkPageSetup *page_setup;
   GtkPrintSettings *print_settings;
@@ -79,6 +80,7 @@ enum {
   WEB_VIEW_CREATED,
   PAGE_CREATED,
   ALLOW_TLS_CERTIFICATE,
+  ALLOW_UNSAFE_BROWSING,
   FORM_AUTH_DATA_SAVE_REQUESTED,
   SENSITIVE_FORM_FOCUSED,
 
@@ -99,7 +101,7 @@ static EphyEmbedShell *embed_shell = NULL;
 
 static void ephy_embed_shell_tabs_catalog_iface_init (EphyTabsCatalogInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (EphyEmbedShell, ephy_embed_shell, GTK_TYPE_APPLICATION,
+G_DEFINE_TYPE_WITH_CODE (EphyEmbedShell, ephy_embed_shell, DZL_TYPE_APPLICATION,
                          G_ADD_PRIVATE (EphyEmbedShell)
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_TABS_CATALOG,
                                                 ephy_embed_shell_tabs_catalog_iface_init))
@@ -168,6 +170,7 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->page_setup);
   g_clear_object (&priv->print_settings);
   g_clear_object (&priv->global_history_service);
+  g_clear_object (&priv->global_gsb_service);
   g_clear_object (&priv->about_handler);
   g_clear_object (&priv->user_content);
   g_clear_object (&priv->downloads_manager);
@@ -334,6 +337,17 @@ web_extension_tls_error_page_message_received_cb (WebKitUserContentManager *mana
   g_signal_emit (shell, signals[ALLOW_TLS_CERTIFICATE], 0, page_id);
 }
 
+static void
+web_extension_unsafe_browsing_error_page_message_received_cb (WebKitUserContentManager *manager,
+                                                              WebKitJavascriptResult   *message,
+                                                              EphyEmbedShell           *shell)
+{
+  guint64 page_id;
+
+  page_id = ephy_embed_utils_get_js_result_as_number (message);
+  g_signal_emit (shell, signals[ALLOW_UNSAFE_BROWSING], 0, page_id);
+}
+
 static void
 web_extension_about_apps_message_received_cb (WebKitUserContentManager *manager,
                                               WebKitJavascriptResult   *message,
@@ -539,7 +553,7 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (priv->global_history_service == NULL) {
     char *filename;
@@ -554,7 +568,7 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
     filename = g_build_filename (ephy_dot_dir (), EPHY_HISTORY_FILE, NULL);
     priv->global_history_service = ephy_history_service_new (filename, mode);
     g_free (filename);
-    g_return_val_if_fail (priv->global_history_service, NULL);
+    g_assert (priv->global_history_service);
     g_signal_connect (priv->global_history_service, "urls-visited",
                       G_CALLBACK (history_service_urls_visited_cb),
                       shell);
@@ -575,6 +589,34 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
   return priv->global_history_service;
 }
 
+/**
+ * ephy_embed_shell_get_global_gsb_service:
+ * @shell: the #EphyEmbedShell
+ *
+ * Return value: (transfer none): the global #EphyGSBService
+ **/
+EphyGSBService *
+ephy_embed_shell_get_global_gsb_service (EphyEmbedShell *shell)
+{
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
+
+  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+
+  if (priv->global_gsb_service == NULL) {
+    char *api_key;
+    char *filename;
+
+    api_key = g_settings_get_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_GSB_API_KEY);
+    filename = g_build_filename (ephy_dot_dir (), EPHY_GSB_FILE, NULL);
+    priv->global_gsb_service = ephy_gsb_service_new (api_key, filename);
+
+    g_free (api_key);
+    g_free (filename);
+  }
+
+  return priv->global_gsb_service;
+}
+
 static void
 snapshot_saved_cb (EphySnapshotService *service,
                    const char          *url,
@@ -597,7 +639,7 @@ ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (priv->encodings == NULL)
     priv->encodings = ephy_encodings_new ();
@@ -931,6 +973,10 @@ ephy_embed_shell_startup (GApplication *application)
 
   G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->startup (application);
 
+  filters_dir = adblock_filters_dir (shell);
+  priv->filters_manager = ephy_filters_manager_new (filters_dir);
+  g_free (filters_dir);
+
   ephy_embed_shell_create_web_context (shell);
 
   ephy_embed_shell_setup_web_extensions_server (shell);
@@ -951,6 +997,12 @@ ephy_embed_shell_startup (GApplication *application)
                     G_CALLBACK (web_extension_tls_error_page_message_received_cb),
                     shell);
 
+  webkit_user_content_manager_register_script_message_handler (priv->user_content,
+                                                               "unsafeBrowsingErrorPage");
+  g_signal_connect (priv->user_content, "script-message-received::unsafeBrowsingErrorPage",
+                    G_CALLBACK (web_extension_unsafe_browsing_error_page_message_received_cb),
+                    shell);
+
   webkit_user_content_manager_register_script_message_handler (priv->user_content,
                                                                "formAuthData");
   g_signal_connect (priv->user_content, "script-message-received::formAuthData",
@@ -1026,10 +1078,6 @@ ephy_embed_shell_startup (GApplication *application)
   ephy_embed_prefs_set_cookie_accept_policy (cookie_manager, cookie_policy);
   g_free (cookie_policy);
 
-  filters_dir = adblock_filters_dir (shell);
-  priv->filters_manager = ephy_filters_manager_new (filters_dir);
-  g_free (filters_dir);
-
 #if ENABLE_HTTPS_EVERYWHERE
     /* We might want to be smarter about this in the future. For now,
      * trigger an update of the rulesets once each time Epiphany is started.
@@ -1230,6 +1278,22 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
                   G_TYPE_NONE, 1,
                   G_TYPE_UINT64);
 
+  /**
+   * EphyEmbedShell::allow-unsafe-browsing:
+   * @shell: the #EphyEmbedShell
+   * @page_id: the identifier of the web page
+   *
+   * Emitted when the web extension requests an exception be
+   * permitted for the unsafe browsing warning on the given page
+   */
+  signals[ALLOW_UNSAFE_BROWSING] =
+    g_signal_new ("allow-unsafe-browsing",
+                  EPHY_TYPE_EMBED_SHELL,
+                  G_SIGNAL_RUN_FIRST,
+                  0, NULL, NULL, NULL,
+                  G_TYPE_NONE, 1,
+                  G_TYPE_UINT64);
+
   /**
    * EphyEmbedShell::form-auth-data-save-requested:
    * @shell: the #EphyEmbedShell
@@ -1291,7 +1355,7 @@ ephy_embed_shell_set_page_setup (EphyEmbedShell *shell,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   char *path;
 
-  g_return_if_fail (EPHY_IS_EMBED_SHELL (shell));
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (page_setup != NULL)
     g_object_ref (page_setup);
@@ -1318,7 +1382,7 @@ ephy_embed_shell_get_page_setup (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (priv->page_setup == NULL) {
     GError *error = NULL;
@@ -1354,7 +1418,7 @@ ephy_embed_shell_set_print_settings (EphyEmbedShell   *shell,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   char *path;
 
-  g_return_if_fail (EPHY_IS_EMBED_SHELL (shell));
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (settings != NULL)
     g_object_ref (settings);
@@ -1382,7 +1446,7 @@ ephy_embed_shell_get_print_settings (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   if (priv->print_settings == NULL) {
     GError *error = NULL;
@@ -1414,7 +1478,7 @@ ephy_embed_shell_get_mode (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), EPHY_EMBED_SHELL_MODE_BROWSER);
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
 
   return priv->mode;
 }
@@ -1442,12 +1506,8 @@ ephy_embed_shell_launch_handler (EphyEmbedShell *shell,
   GList *list = NULL;
   gboolean ret = FALSE;
 
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), FALSE);
-  g_return_val_if_fail (file || mime_type, FALSE);
-
-  if (ephy_is_running_inside_flatpak ()) {
-    return ephy_file_launch_file_via_uri_handler (file);
-  }
+  g_assert (EPHY_IS_EMBED_SHELL (shell));
+  g_assert (file || mime_type);
 
   app = ephy_file_launcher_get_app_info_for_file (file, mime_type);
 
