@@ -21,10 +21,12 @@
 
 #pragma once
 
+#include <dazzle.h>
 #include <webkit2/webkit2.h>
 
 #include "ephy-downloads-manager.h"
 #include "ephy-encodings.h"
+#include "ephy-gsb-service.h"
 #include "ephy-history-service.h"
 #include "ephy-permissions-manager.h"
 #include "ephy-search-engine-manager.h"
@@ -33,7 +35,7 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_EMBED_SHELL (ephy_embed_shell_get_type ())
 
-G_DECLARE_DERIVABLE_TYPE (EphyEmbedShell, ephy_embed_shell, EPHY, EMBED_SHELL, GtkApplication)
+G_DECLARE_DERIVABLE_TYPE (EphyEmbedShell, ephy_embed_shell, EPHY, EMBED_SHELL, DzlApplication)
 
 typedef enum
 {
@@ -48,7 +50,7 @@ typedef enum
 
 struct _EphyEmbedShellClass
 {
-  GtkApplicationClass parent_class;
+  DzlApplicationClass parent_class;
 
   void    (* restored_window)  (EphyEmbedShell *shell);
 };
@@ -57,6 +59,7 @@ EphyEmbedShell    *ephy_embed_shell_get_default                (void);
 WebKitWebContext  *ephy_embed_shell_get_web_context            (EphyEmbedShell   *shell);
 EphyHistoryService
                   *ephy_embed_shell_get_global_history_service (EphyEmbedShell   *shell);
+EphyGSBService    *ephy_embed_shell_get_global_gsb_service     (EphyEmbedShell   *shell);
 EphyEncodings     *ephy_embed_shell_get_encodings              (EphyEmbedShell   *shell);
 void               ephy_embed_shell_restored_window            (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_page_setup             (EphyEmbedShell   *shell,
