@@ -126,7 +126,6 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "file", colonpos) &&
                      g_ascii_strncasecmp (address, "javascript", colonpos) &&
                      g_ascii_strncasecmp (address, "data", colonpos) &&
-                     g_ascii_strncasecmp (address, "blob", colonpos) &&
                      g_ascii_strncasecmp (address, "about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
@@ -153,7 +152,7 @@ is_public_domain (const char *address)
     return FALSE;
 
   if (g_regex_match (get_domain_regex (), host, 0, NULL)) {
-    if (g_str_equal (host, "localhost"))
+    if (!strcmp (host, "localhost"))
       retval = TRUE;
     else {
       const char *end;
@@ -224,7 +223,7 @@ ephy_embed_utils_normalize_address (const char *address)
 {
   char *effective_address = NULL;
 
-  g_return_val_if_fail (address, NULL);
+  g_assert (address);
 
   if (is_bang_search (address)) {
     EphyEmbedShell *shell;
@@ -239,7 +238,7 @@ ephy_embed_utils_normalize_address (const char *address)
   if (ephy_embed_utils_address_is_existing_absolute_filename (address))
     return g_strconcat ("file://", address, NULL);
 
-  if (g_str_has_prefix (address, "about:") && !g_str_equal (address, "about:blank"))
+  if (g_str_has_prefix (address, "about:") && strcmp (address, "about:blank"))
     return g_strconcat (EPHY_ABOUT_SCHEME, address + strlen ("about"), NULL);
 
   if (!ephy_embed_utils_address_has_web_scheme (address)) {
@@ -329,7 +328,7 @@ ephy_embed_utils_is_no_show_address (const char *address)
     return FALSE;
 
   for (i = 0; do_not_show_address[i]; i++)
-    if (g_str_equal (address, do_not_show_address[i]))
+    if (!strcmp (address, do_not_show_address[i]))
       return TRUE;
 
   return FALSE;
