@@ -65,7 +65,8 @@ typedef enum {
   EPHY_WEB_VIEW_ERROR_PAGE_NETWORK_ERROR,
   EPHY_WEB_VIEW_ERROR_PAGE_CRASH,
   EPHY_WEB_VIEW_ERROR_PROCESS_CRASH,
-  EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE
+  EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE,
+  EPHY_WEB_VIEW_ERROR_UNSAFE_BROWSING
 } EphyWebViewErrorPage;
 
 GType                      ephy_web_view_chrome_get_type          (void);
@@ -113,7 +114,8 @@ EphyWebViewErrorPage       ephy_web_view_get_error_page           (EphyWebView
 void                       ephy_web_view_load_error_page          (EphyWebView               *view,
                                                                    const char                *uri,
                                                                    EphyWebViewErrorPage       page,
-                                                                   GError                    *error);
+                                                                   GError                    *error,
+                                                                   gpointer                   user_data);
 void                       ephy_web_view_get_best_web_app_icon    (EphyWebView               *view,
                                                                    GCancellable              *cancellable,
                                                                    GAsyncReadyCallback        callback,
