@@ -603,7 +603,7 @@ pre_fill_form (EphyEmbedFormAuth *form_auth)
     g_object_get (password_node, "name", &password_field_name, NULL);
 
   /* The username node is empty, so pre-fill with the default. */
-  if (username != NULL && g_str_equal (username, ""))
+  if (!g_strcmp0 (username, ""))
     g_clear_pointer (&username, g_free);
 
   uri_str = soup_uri_to_string (uri, FALSE);
@@ -1572,7 +1572,7 @@ ephy_prefs_sync_user_cb (GSettings *settings,
    */
   if (ephy_sync_utils_user_is_signed_in ())
     ephy_web_extension_create_sync_service (extension);
-  else if (extension->sync_service)
+  else
     ephy_web_extension_destroy_sync_service (extension);
 }
 
@@ -1692,7 +1692,7 @@ ephy_web_extension_initialize (EphyWebExtension   *extension,
 {
   GDBusAuthObserver *observer;
 
-  g_return_if_fail (EPHY_IS_WEB_EXTENSION (extension));
+  g_assert (EPHY_IS_WEB_EXTENSION (extension));
 
   if (extension->initialized)
     return;
