@@ -230,8 +230,8 @@ void
 ephy_history_record_set_id (EphyHistoryRecord *self,
                             const char        *id)
 {
-  g_return_if_fail (EPHY_IS_HISTORY_RECORD (self));
-  g_return_if_fail (id);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
+  g_assert (id);
 
   g_free (self->id);
   self->id = g_strdup (id);
@@ -240,7 +240,7 @@ ephy_history_record_set_id (EphyHistoryRecord *self,
 const char *
 ephy_history_record_get_id (EphyHistoryRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_HISTORY_RECORD (self), NULL);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
 
   return self->id;
 }
@@ -248,7 +248,7 @@ ephy_history_record_get_id (EphyHistoryRecord *self)
 const char *
 ephy_history_record_get_title (EphyHistoryRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_HISTORY_RECORD (self), NULL);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
 
   return self->title;
 }
@@ -256,7 +256,7 @@ ephy_history_record_get_title (EphyHistoryRecord *self)
 const char *
 ephy_history_record_get_uri (EphyHistoryRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_HISTORY_RECORD (self), NULL);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
 
   return self->uri;
 }
@@ -266,8 +266,8 @@ ephy_history_record_get_last_visit_time (EphyHistoryRecord *self)
 {
   EphyHistoryRecordVisit *visit;
 
-  g_return_val_if_fail (EPHY_IS_HISTORY_RECORD (self), -1);
-  g_return_val_if_fail (self->visits, -1);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
+  g_assert (self->visits);
 
   if (g_sequence_is_empty (self->visits))
     return -1;
@@ -284,7 +284,7 @@ ephy_history_record_add_visit_time (EphyHistoryRecord *self,
 {
   EphyHistoryRecordVisit *visit;
 
-  g_return_val_if_fail (EPHY_IS_HISTORY_RECORD (self), FALSE);
+  g_assert (EPHY_IS_HISTORY_RECORD (self));
 
   visit = ephy_history_record_visit_new (visit_time, EPHY_PAGE_VISIT_LINK);
   if (g_sequence_lookup (self->visits, visit,
@@ -307,18 +307,16 @@ serializable_serialize_property (JsonSerializable *serializable,
                                  const GValue     *value,
                                  GParamSpec       *pspec)
 {
-  if (G_VALUE_HOLDS_STRING (value) && g_value_get_string (value) == NULL) {
-    JsonNode *node = json_node_new (JSON_NODE_VALUE);
-    json_node_set_string (node, "");
-    return node;
-  }
-
   if (!g_strcmp0 (name, "visits")) {
-    JsonNode *node = json_node_new (JSON_NODE_ARRAY);
-    JsonArray *array = json_array_new ();
-    GSequence *visits = g_value_get_pointer (value);
+    JsonNode *node;
+    JsonArray *array;
+    GSequence *visits;
     GSequenceIter *it;
 
+    node = json_node_new (JSON_NODE_ARRAY);
+    array = json_array_new ();
+    visits = g_value_get_pointer (value);
+
     if (visits != NULL) {
       for (it = g_sequence_get_begin_iter (visits); !g_sequence_iter_is_end (it); it = g_sequence_iter_next (it)) {
         EphyHistoryRecordVisit *visit = g_sequence_get (it);
@@ -344,14 +342,12 @@ serializable_deserialize_property (JsonSerializable *serializable,
                                    GParamSpec       *pspec,
                                    JsonNode         *node)
 {
-  if (G_VALUE_HOLDS_STRING (value) && JSON_NODE_HOLDS_NULL (node)) {
-    g_value_set_string (value, "");
-    return TRUE;
-  }
-
   if (!g_strcmp0 (name, "visits")) {
-    JsonArray *array = json_node_get_array (node);
-    GSequence *visits = g_sequence_new ((GDestroyNotify)ephy_history_record_visit_free);
+    JsonArray *array;
+    GSequence *visits;
+
+    array = json_node_get_array (node);
+    visits = g_sequence_new ((GDestroyNotify)ephy_history_record_visit_free);
 
     for (guint i = 0; i < json_array_get_length (array); i++) {
       JsonObject *object = json_node_get_object (json_array_get_element (array, i));
@@ -382,7 +378,7 @@ synchronizable_get_id (EphySynchronizable *synchronizable)
   return ephy_history_record_get_id (EPHY_HISTORY_RECORD (synchronizable));
 }
 
-static gint64
+static double
 synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 {
   /* No implementation.
@@ -393,7 +389,7 @@ synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 
 static void
 synchronizable_set_server_time_modified (EphySynchronizable *synchronizable,
-                                         gint64              server_time_modified)
+                                         double              server_time_modified)
 {
   /* No implementation.
    * We don't care about the server time modified of history records.
