@@ -168,7 +168,7 @@ ephy_open_tabs_record_new (const char *id,
 const char *
 ephy_open_tabs_record_get_id (EphyOpenTabsRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_OPEN_TABS_RECORD (self), NULL);
+  g_assert (EPHY_IS_OPEN_TABS_RECORD (self));
 
   return self->id;
 }
@@ -176,7 +176,7 @@ ephy_open_tabs_record_get_id (EphyOpenTabsRecord *self)
 const char *
 ephy_open_tabs_record_get_client_name (EphyOpenTabsRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_OPEN_TABS_RECORD (self), NULL);
+  g_assert (EPHY_IS_OPEN_TABS_RECORD (self));
 
   return self->client_name;
 }
@@ -184,7 +184,7 @@ ephy_open_tabs_record_get_client_name (EphyOpenTabsRecord *self)
 GList *
 ephy_open_tabs_record_get_tabs (EphyOpenTabsRecord *self)
 {
-  g_return_val_if_fail (EPHY_IS_OPEN_TABS_RECORD (self), NULL);
+  g_assert (EPHY_IS_OPEN_TABS_RECORD (self));
 
   return self->tabs;
 }
@@ -198,9 +198,9 @@ ephy_open_tabs_record_add_tab (EphyOpenTabsRecord *self,
   JsonObject *tab;
   JsonArray *url_history;
 
-  g_return_if_fail (EPHY_IS_OPEN_TABS_RECORD (self));
-  g_return_if_fail (title);
-  g_return_if_fail (url);
+  g_assert (EPHY_IS_OPEN_TABS_RECORD (self));
+  g_assert (title);
+  g_assert (url);
 
   tab = json_object_new ();
   json_object_set_string_member (tab, "title", title);
@@ -220,12 +220,6 @@ serializable_serialize_property (JsonSerializable *serializable,
                                  const GValue     *value,
                                  GParamSpec       *pspec)
 {
-  if (G_VALUE_HOLDS_STRING (value) && g_value_get_string (value) == NULL) {
-    JsonNode *node = json_node_new (JSON_NODE_VALUE);
-    json_node_set_string (node, "");
-    return node;
-  }
-
   if (!g_strcmp0 (name, "tabs")) {
     JsonNode *node = json_node_new (JSON_NODE_ARRAY);
     JsonArray *array = json_array_new ();
@@ -248,11 +242,6 @@ serializable_deserialize_property (JsonSerializable *serializable,
                                    GParamSpec       *pspec,
                                    JsonNode         *node)
 {
-  if (G_VALUE_HOLDS_STRING (value) && JSON_NODE_HOLDS_NULL (node)) {
-    g_value_set_string (value, "");
-    return TRUE;
-  }
-
   if (!g_strcmp0 (name, "tabs")) {
     JsonArray *array;
     GList *tabs = NULL;
@@ -282,7 +271,7 @@ synchronizable_get_id (EphySynchronizable *synchronizable)
   return EPHY_OPEN_TABS_RECORD (synchronizable)->id;
 }
 
-static gint64
+static double
 synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 {
   /* No implementation.
@@ -293,7 +282,7 @@ synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 
 static void
 synchronizable_set_server_time_modified (EphySynchronizable *synchronizable,
-                                         gint64              server_time_modified)
+                                         double              server_time_modified)
 {
   /* No implementation.
    * We don't care about the server time modified of open tabs records.
