@@ -22,10 +22,9 @@
 #include "ephy-download-widget.h"
 
 #include "ephy-debug.h"
-#include "ephy-downloads-manager.h"
-#include "ephy-embed-shell.h"
-#include "ephy-flatpak-utils.h"
 #include "ephy-uri-helpers.h"
+#include "ephy-embed-shell.h"
+#include "ephy-downloads-manager.h"
 
 #include <glib/gi18n.h>
 #include <webkit2/webkit2.h>
@@ -275,7 +274,7 @@ widget_action_button_clicked_cb (EphyDownloadWidget *widget)
     ephy_downloads_manager_remove_download (manager, widget->download);
   } else {
     ephy_download_do_download_action (widget->download,
-                                      ephy_is_running_inside_flatpak () ? EPHY_DOWNLOAD_ACTION_OPEN : EPHY_DOWNLOAD_ACTION_BROWSE_TO,
+                                      EPHY_DOWNLOAD_ACTION_BROWSE_TO,
                                       gtk_get_current_event_time ());
   }
 }
@@ -487,7 +486,7 @@ ephy_download_widget_init (EphyDownloadWidget *widget)
 EphyDownload *
 ephy_download_widget_get_download (EphyDownloadWidget *widget)
 {
-  g_return_val_if_fail (EPHY_IS_DOWNLOAD_WIDGET (widget), NULL);
+  g_assert (EPHY_IS_DOWNLOAD_WIDGET (widget));
   return widget->download;
 }
 
@@ -505,7 +504,7 @@ ephy_download_widget_new (EphyDownload *ephy_download)
 {
   EphyDownloadWidget *widget;
 
-  g_return_val_if_fail (EPHY_IS_DOWNLOAD (ephy_download), NULL);
+  g_assert (EPHY_IS_DOWNLOAD (ephy_download));
 
   widget = g_object_new (EPHY_TYPE_DOWNLOAD_WIDGET,
                          "download", ephy_download, NULL);
