@@ -39,13 +39,14 @@ struct _EphyBookmark {
   GSequence   *tags;
   gint64       time_added;
 
-  /* Firefox Sync specific fields. */
+  /* Firefox Sync specific fields.
+   * Time modified timestamp must be double to match server's precision. */
   char        *id;
   char        *type;
   char        *parent_id;
   char        *parent_name;
   gboolean     load_in_sidebar;
-  gint64       server_time_modified;
+  double       server_time_modified;
 };
 
 static void json_serializable_iface_init (JsonSerializableIface *iface);
@@ -304,7 +305,7 @@ void
 ephy_bookmark_set_time_added (EphyBookmark *self,
                               gint64        time_added)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
   g_assert (time_added >= 0);
 
   self->time_added = time_added;
@@ -313,7 +314,7 @@ ephy_bookmark_set_time_added (EphyBookmark *self,
 gint64
 ephy_bookmark_get_time_added (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), 0);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->time_added;
 }
@@ -322,7 +323,7 @@ ephy_bookmark_get_time_added (EphyBookmark *self)
 void
 ephy_bookmark_set_url (EphyBookmark *self, const char *url)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   g_free (self->url);
   self->url = g_strdup (url);
@@ -331,7 +332,7 @@ ephy_bookmark_set_url (EphyBookmark *self, const char *url)
 const char *
 ephy_bookmark_get_url (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->url;
 }
@@ -339,7 +340,7 @@ ephy_bookmark_get_url (EphyBookmark *self)
 void
 ephy_bookmark_set_title (EphyBookmark *self, const char *title)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   g_free (self->title);
   self->title = g_strdup (title);
@@ -349,7 +350,7 @@ ephy_bookmark_set_title (EphyBookmark *self, const char *title)
 const char *
 ephy_bookmark_get_title (EphyBookmark *bookmark)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (bookmark), NULL);
+  g_assert (EPHY_IS_BOOKMARK (bookmark));
 
   return bookmark->title;
 }
@@ -358,8 +359,8 @@ void
 ephy_bookmark_set_id (EphyBookmark *self,
                       const char   *id)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (id != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (id != NULL);
 
   g_free (self->id);
   self->id = g_strdup (id);
@@ -368,7 +369,7 @@ ephy_bookmark_set_id (EphyBookmark *self,
 const char *
 ephy_bookmark_get_id (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->id;
 }
@@ -380,7 +381,7 @@ ephy_bookmark_set_is_uploaded (EphyBookmark *self,
 
   /* FIXME: This is no longer used for Firefox Sync, but bookmarks import/export
    * expects it. We need to delete it and write a migrator for bookmarks. */
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
+  g_assert (EPHY_IS_BOOKMARK (self));
 }
 
 gboolean
@@ -388,7 +389,7 @@ ephy_bookmark_is_uploaded (EphyBookmark *self)
 {
   /* FIXME: This is no longer used for Firefox Sync, but bookmarks import/export
    * expects it. We need to delete it and write a migrator for bookmarks. */
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), FALSE);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return FALSE;
 }
@@ -400,8 +401,8 @@ ephy_bookmark_add_tag (EphyBookmark *self,
   GSequenceIter *tag_iter;
   GSequenceIter *prev_tag_iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_search (self->tags,
                                 (gpointer)tag,
@@ -422,8 +423,8 @@ ephy_bookmark_remove_tag (EphyBookmark *self,
 {
   GSequenceIter *tag_iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARK (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_lookup (self->tags,
                                 (gpointer)tag,
@@ -441,8 +442,8 @@ ephy_bookmark_has_tag (EphyBookmark *self, const char *tag)
 {
   GSequenceIter *tag_iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), FALSE);
-  g_return_val_if_fail (tag != NULL, FALSE);
+  g_assert (EPHY_IS_BOOKMARK (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_lookup (self->tags,
                                 (gpointer)tag,
@@ -455,7 +456,7 @@ ephy_bookmark_has_tag (EphyBookmark *self, const char *tag)
 GSequence *
 ephy_bookmark_get_tags (EphyBookmark *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARK (self), NULL);
+  g_assert (EPHY_IS_BOOKMARK (self));
 
   return self->tags;
 }
@@ -519,17 +520,16 @@ serializable_serialize_property (JsonSerializable *serializable,
                                  const GValue     *value,
                                  GParamSpec       *pspec)
 {
-  if (G_VALUE_HOLDS_STRING (value) && g_value_get_string (value) == NULL) {
-    JsonNode *node = json_node_new (JSON_NODE_VALUE);
-    json_node_set_string (node, "");
-    return node;
-  }
+  JsonNode *node = NULL;
 
   if (g_strcmp0 (name, "tags") == 0) {
-    JsonNode *node = json_node_new (JSON_NODE_ARRAY);
-    JsonArray *array = json_array_new ();
-    GSequence *tags = g_value_get_pointer (value);
+    GSequence *tags;
     GSequenceIter *iter;
+    JsonArray *array;
+
+    node = json_node_new (JSON_NODE_ARRAY);
+    array = json_array_new ();
+    tags = g_value_get_pointer (value);
 
     if (tags != NULL) {
       for (iter = g_sequence_get_begin_iter (tags);
@@ -540,15 +540,13 @@ serializable_serialize_property (JsonSerializable *serializable,
     }
 
     json_node_set_array (node, array);
-
-    return node;
+  } else if (!g_strcmp0 (name, "time-added")) {
+    /* This is not a Firefox bookmark property, skip it.  */
+  } else {
+    node = json_serializable_default_serialize_property (serializable, name, value, pspec);
   }
 
-  /* This is not a Firefox bookmark property, skip it. */
-  if (!g_strcmp0 (name, "time-added"))
-    return NULL;
-
-  return json_serializable_default_serialize_property (serializable, name, value, pspec);
+  return node;
 }
 
 static gboolean
@@ -558,16 +556,15 @@ serializable_deserialize_property (JsonSerializable *serializable,
                                    GParamSpec       *pspec,
                                    JsonNode         *node)
 {
-  if (G_VALUE_HOLDS_STRING (value) && JSON_NODE_HOLDS_NULL (node)) {
-    g_value_set_string (value, "");
-    return TRUE;
-  }
-
   if (g_strcmp0 (name, "tags") == 0) {
-    GSequence *tags = g_sequence_new (g_free);
-    JsonArray *array = json_node_get_array (node);
+    GSequence *tags;
+    JsonArray *array;
     const char *tag;
 
+    g_assert (JSON_NODE_HOLDS_ARRAY (node));
+    array = json_node_get_array (node);
+    tags = g_sequence_new (g_free);
+
     for (gsize i = 0; i < json_array_get_length (array); i++) {
       tag = json_node_get_string (json_array_get_element (array, i));
       g_sequence_insert_sorted (tags, g_strdup (tag),
@@ -595,7 +592,7 @@ synchronizable_get_id (EphySynchronizable *synchronizable)
   return ephy_bookmark_get_id (EPHY_BOOKMARK (synchronizable));
 }
 
-static gint64
+static double
 synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 {
   return EPHY_BOOKMARK (synchronizable)->server_time_modified;
@@ -603,7 +600,7 @@ synchronizable_get_server_time_modified (EphySynchronizable *synchronizable)
 
 static void
 synchronizable_set_server_time_modified (EphySynchronizable *synchronizable,
-                                         gint64              server_time_modified)
+                                         double              server_time_modified)
 {
   EPHY_BOOKMARK (synchronizable)->server_time_modified = server_time_modified;
 }
