@@ -338,8 +338,8 @@ void
 ephy_bookmarks_manager_add_bookmark (EphyBookmarksManager *self,
                                      EphyBookmark         *bookmark)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self));
-  g_return_if_fail (EPHY_IS_BOOKMARK (bookmark));
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (EPHY_IS_BOOKMARK (bookmark));
 
   ephy_bookmarks_manager_add_bookmark_internal (self, bookmark, TRUE);
   g_signal_emit_by_name (self, "synchronizable-modified", bookmark, FALSE);
@@ -351,8 +351,8 @@ ephy_bookmarks_manager_add_bookmarks (EphyBookmarksManager *self,
 {
   GSequenceIter *iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self));
-  g_return_if_fail (bookmarks != NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (bookmarks != NULL);
 
   for (iter = g_sequence_get_begin_iter (bookmarks);
        !g_sequence_iter_is_end (iter); iter = g_sequence_iter_next (iter)) {
@@ -407,8 +407,8 @@ ephy_bookmarks_manager_remove_bookmark_internal (EphyBookmarksManager *self,
 void ephy_bookmarks_manager_remove_bookmark (EphyBookmarksManager *self,
                                              EphyBookmark         *bookmark)
 {
-  g_return_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self));
-  g_return_if_fail (EPHY_IS_BOOKMARK (bookmark));
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (EPHY_IS_BOOKMARK (bookmark));
 
   g_signal_emit_by_name (self, "synchronizable-deleted", bookmark);
   ephy_bookmarks_manager_remove_bookmark_internal (self, bookmark);
@@ -420,8 +420,8 @@ ephy_bookmarks_manager_get_bookmark_by_url (EphyBookmarksManager *self,
 {
   GSequenceIter *iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), FALSE);
-  g_return_val_if_fail (url != NULL, FALSE);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (url != NULL);
 
   for (iter = g_sequence_get_begin_iter (self->bookmarks);
          !g_sequence_iter_is_end (iter);
@@ -441,8 +441,8 @@ ephy_bookmarks_manager_get_bookmark_by_id (EphyBookmarksManager *self,
 {
   GSequenceIter *iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), FALSE);
-  g_return_val_if_fail (id != NULL, FALSE);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (id != NULL);
 
   for (iter = g_sequence_get_begin_iter (self->bookmarks);
        !g_sequence_iter_is_end (iter);
@@ -462,8 +462,8 @@ ephy_bookmarks_manager_create_tag (EphyBookmarksManager *self, const char *tag)
   GSequenceIter *tag_iter;
   GSequenceIter *prev_tag_iter;
 
-  g_return_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (tag != NULL);
 
   tag_iter = g_sequence_search (self->tags,
                                 (gpointer)tag,
@@ -484,8 +484,8 @@ ephy_bookmarks_manager_delete_tag (EphyBookmarksManager *self, const char *tag)
   GSequenceIter *iter = NULL;
   int position;
 
-  g_return_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self));
-  g_return_if_fail (tag != NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (tag != NULL);
 
   if (strcmp (tag, EPHY_BOOKMARKS_FAVORITES_TAG) == 0)
     return;
@@ -511,8 +511,8 @@ ephy_bookmarks_manager_tag_exists (EphyBookmarksManager *self, const char *tag)
 {
   GSequenceIter *iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), FALSE);
-  g_return_val_if_fail (tag != NULL, FALSE);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
+  g_assert (tag != NULL);
 
   iter = g_sequence_lookup (self->tags,
                             (gpointer)tag,
@@ -525,7 +525,7 @@ ephy_bookmarks_manager_tag_exists (EphyBookmarksManager *self, const char *tag)
 GSequence *
 ephy_bookmarks_manager_get_bookmarks (EphyBookmarksManager *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
   return self->bookmarks;
 }
@@ -537,7 +537,7 @@ ephy_bookmarks_manager_get_bookmarks_with_tag (EphyBookmarksManager *self,
   GSequence *bookmarks;
   GSequenceIter *iter;
 
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
   bookmarks = g_sequence_new (g_object_unref);
 
@@ -574,7 +574,7 @@ ephy_bookmarks_manager_get_bookmarks_with_tag (EphyBookmarksManager *self,
 GSequence *
 ephy_bookmarks_manager_get_tags (EphyBookmarksManager *self)
 {
-  g_return_val_if_fail (EPHY_IS_BOOKMARKS_MANAGER (self), NULL);
+  g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
   return self->tags;
 }
@@ -599,7 +599,7 @@ ephy_bookmarks_manager_save_to_file_finish (EphyBookmarksManager *self,
                                             GAsyncResult         *result,
                                             GError              **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
+  g_assert (g_task_is_valid (result, self));
 
   return g_task_propagate_boolean (G_TASK (result), error);
 }
@@ -685,7 +685,7 @@ synchronizable_manager_set_is_initial_sync (EphySynchronizableManager *manager,
   ephy_sync_utils_set_bookmarks_sync_is_initial (is_initial);
 }
 
-static gint64
+static double
 synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 {
   return ephy_sync_utils_get_bookmarks_sync_time ();
@@ -693,7 +693,7 @@ synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 
 static void
 synchronizable_manager_set_sync_time (EphySynchronizableManager *manager,
-                                      gint64                     sync_time)
+                                      double                     sync_time)
 {
   ephy_sync_utils_set_bookmarks_sync_time (sync_time);
 }
@@ -730,20 +730,19 @@ synchronizable_manager_save (EphySynchronizableManager *manager,
                                              NULL);
 }
 
-static GPtrArray *
+static GList *
 ephy_bookmarks_manager_handle_initial_merge (EphyBookmarksManager *self,
                                              GList                *remote_bookmarks)
 {
-  GPtrArray *to_upload;
+  GList *to_upload = NULL;
   EphyBookmark *bookmark;
   GSequence *bookmarks;
   GSequenceIter *iter;
   GHashTable *dont_upload;
-  gint64 timestamp;
+  double timestamp;
 
   g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
-  to_upload = g_ptr_array_new_with_free_func (g_object_unref);
   dont_upload = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
   for (GList *l = remote_bookmarks; l && l->data; l = l->next) {
@@ -811,7 +810,7 @@ next:
        !g_sequence_iter_is_end (iter); iter = g_sequence_iter_next (iter)) {
     bookmark = g_sequence_get (iter);
     if (!g_hash_table_contains (dont_upload, ephy_bookmark_get_id (bookmark)))
-      g_ptr_array_add (to_upload, g_object_ref (bookmark));
+      to_upload = g_list_prepend (to_upload, g_object_ref (bookmark));
   }
 
   /* Commit changes to file. */
@@ -823,19 +822,17 @@ next:
   return to_upload;
 }
 
-static GPtrArray *
+static GList *
 ephy_bookmarks_manager_handle_regular_merge (EphyBookmarksManager *self,
                                              GList                *updated_bookmarks,
                                              GList                *deleted_bookmarks)
 {
-  GPtrArray *to_upload;
+  GList *to_upload = NULL;
   EphyBookmark *bookmark;
-  gint64 timestamp;
+  double timestamp;
 
   g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
-  to_upload = g_ptr_array_new_with_free_func (g_object_unref);
-
   for (GList *l = deleted_bookmarks; l && l->data; l = l->next) {
     bookmark = ephy_bookmarks_manager_get_bookmark_by_id (self, ephy_bookmark_get_id (l->data));
     if (bookmark)
@@ -877,7 +874,7 @@ ephy_bookmarks_manager_handle_regular_merge (EphyBookmarksManager *self,
         ephy_bookmarks_manager_copy_tags_from_bookmark (self, bookmark, l->data);
         timestamp = ephy_synchronizable_get_server_time_modified (l->data);
         ephy_synchronizable_set_server_time_modified (EPHY_SYNCHRONIZABLE (bookmark), timestamp);
-        g_ptr_array_add (to_upload, g_object_ref (bookmark));
+        to_upload = g_list_prepend (to_upload, g_object_ref (bookmark));
       } else {
         /* Different id, different url. Add remote bookmark. */
         ephy_bookmarks_manager_add_bookmark_internal (self, l->data, FALSE);
@@ -909,14 +906,17 @@ synchronizable_manager_merge (EphySynchronizableManager              *manager,
                               gpointer                                user_data)
 {
   EphyBookmarksManager *self = EPHY_BOOKMARKS_MANAGER (manager);
-  GPtrArray *to_upload;
+  GList *to_upload = NULL;
 
   if (is_initial)
-    to_upload = ephy_bookmarks_manager_handle_initial_merge (self, remotes_updated);
+    to_upload = ephy_bookmarks_manager_handle_initial_merge (self,
+                                                             remotes_updated);
   else
-    to_upload = ephy_bookmarks_manager_handle_regular_merge (self, remotes_updated, remotes_deleted);
+    to_upload = ephy_bookmarks_manager_handle_regular_merge (self,
+                                                             remotes_updated,
+                                                             remotes_deleted);
 
-  callback (to_upload, user_data);
+  callback (to_upload, FALSE, user_data);
 }
 
 static void
