@@ -230,7 +230,7 @@ ephy_session_undo_close_tab (EphySession *session)
   EphyNotebook *notebook;
   EphyNewTabFlags flags = EPHY_NEW_TAB_JUMP;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
+  g_assert (EPHY_IS_SESSION (session));
 
   tab = g_queue_pop_head (session->closed_tabs);
   if (tab == NULL)
@@ -317,7 +317,7 @@ ephy_session_tab_closed (EphySession  *session,
 gboolean
 ephy_session_get_can_undo_tab_closed (EphySession *session)
 {
-  g_return_val_if_fail (EPHY_IS_SESSION (session), FALSE);
+  g_assert (EPHY_IS_SESSION (session));
 
   return g_queue_is_empty (session->closed_tabs) == FALSE;
 }
@@ -505,7 +505,7 @@ ephy_session_close (EphySession *session)
 {
   EphyPrefsRestoreSessionPolicy policy;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
+  g_assert (EPHY_IS_SESSION (session));
 
   LOG ("ephy_session_close");
 
@@ -563,7 +563,7 @@ session_tab_new (EphyEmbed   *embed,
   /* Do not store ephy-about: URIs, they are not valid for loading. */
   if (g_str_has_prefix (address, EPHY_ABOUT_SCHEME)) {
     session_tab->url = g_strconcat ("about", address + EPHY_ABOUT_SCHEME_LEN, NULL);
-  } else if (g_str_equal (address, "about:blank")) {
+  } else if (!strcmp (address, "about:blank")) {
     /* EphyWebView address is NULL between load_uri() and WEBKIT_LOAD_STARTED,
      * but WebKitWebView knows the pending API request URL, so use that instead of about:blank.
      */
@@ -822,41 +822,22 @@ save_session_in_thread_finished_cb (GObject      *source_object,
 static gboolean
 session_seems_sane (GList *windows)
 {
-  for (GList *w = windows; w != NULL; w = w->next) {
-    for (GList *t = ((SessionWindow *)w->data)->tabs; t != NULL; t = t->next) {
-      const char *url = ((SessionTab *)t->data)->url;
-      SoupURI *uri;
-      gboolean sane = FALSE;
+  GList *w;
+  GList *t;
 
-      /* NULL URLs are possible when an invalid URL is opened by JS.
-       * E.g. <script>win = window.open("blah", "WIN");</script>
-       */
-      if (url == NULL)
-        continue;
-
-      /* Blank URLs can occur in some situations. Just ignore these, as they
-       * are harmless and not an indicator of a corrupted session.
-       */
-      if (strcmp (url, "") == 0)
-        continue;
-
-      /* Ignore fake about "URLs." */
-      if (g_str_has_prefix (url, "about:"))
-        continue;
-
-      uri = soup_uri_new (url);
-      if (uri) {
-        if (uri->host != NULL ||
-            uri->scheme == SOUP_URI_SCHEME_DATA ||
-            uri->scheme == SOUP_URI_SCHEME_FILE)
-          sane = TRUE;
-        soup_uri_free (uri);
-      }
-
-      if (!sane) {
-        g_critical ("Refusing to save session due to invalid URL %s", url);
-        return FALSE;
-      }
+  for (w = windows; w != NULL; w = w->next) {
+    for (t = ((SessionWindow *)w->data)->tabs; t != NULL; t = t->next) {
+       const char *url = ((SessionTab *)t->data)->url;
+       SoupURI *uri = soup_uri_new (url);
+       if (uri) {
+         soup_uri_free (uri);
+       }
+       /* Blank URLs can occur in some situations. Don't save them, but also
+        * do not torpedo the entire session as it's not a bug. */
+       else if (strcmp (url, "") != 0) {
+         g_critical ("Refusing to save session due to invalid URL %s", url);
+         return FALSE;
+       }
     }
   }
 
@@ -1004,7 +985,7 @@ ephy_session_save (EphySession *session)
 {
   EphyPrefsRestoreSessionPolicy policy;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
+  g_assert (EPHY_IS_SESSION (session));
 
   if (session->save_source_id) {
     return;
@@ -1037,7 +1018,7 @@ confirm_before_recover (EphyWindow *window, const char *url, const char *title)
                                    0);
 
   ephy_web_view_load_error_page (ephy_embed_get_web_view (embed), url,
-                                 EPHY_WEB_VIEW_ERROR_PAGE_CRASH, NULL);
+                                 EPHY_WEB_VIEW_ERROR_PAGE_CRASH, NULL, NULL);
 }
 
 static void
@@ -1418,8 +1399,8 @@ ephy_session_load_from_stream (EphySession        *session,
   GMarkupParseContext *parser;
   LoadFromStreamAsyncData *data;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
-  g_return_if_fail (G_IS_INPUT_STREAM (stream));
+  g_assert (EPHY_IS_SESSION (session));
+  g_assert (G_IS_INPUT_STREAM (stream));
 
   g_application_hold (G_APPLICATION (ephy_shell_get_default ()));
 
@@ -1457,7 +1438,7 @@ ephy_session_load_from_stream_finish (EphySession  *session,
                                       GAsyncResult *result,
                                       GError      **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, session), FALSE);
+  g_assert (g_task_is_valid (result, session));
 
   return g_task_propagate_boolean (G_TASK (result), error);
 }
@@ -1557,8 +1538,8 @@ ephy_session_load (EphySession        *session,
   GTask *task;
   LoadAsyncData *data;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
-  g_return_if_fail (filename);
+  g_assert (EPHY_IS_SESSION (session));
+  g_assert (filename);
 
   LOG ("ephy_sesion_load %s", filename);
 
@@ -1593,7 +1574,7 @@ ephy_session_load_finish (EphySession  *session,
                           GAsyncResult *result,
                           GError      **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, session), FALSE);
+  g_assert (g_task_is_valid (result, session));
 
   return g_task_propagate_boolean (G_TASK (result), error);
 }
@@ -1679,7 +1660,7 @@ ephy_session_resume_finish (EphySession  *session,
                             GAsyncResult *result,
                             GError      **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, session), FALSE);
+  g_assert (g_task_is_valid (result, session));
 
   return g_task_propagate_boolean (G_TASK (result), error);
 }
@@ -1691,7 +1672,7 @@ ephy_session_clear (EphySession *session)
   EphyShell *shell;
   GList *windows, *p;
 
-  g_return_if_fail (EPHY_IS_SESSION (session));
+  g_assert (EPHY_IS_SESSION (session));
 
   shell = ephy_shell_get_default ();
   windows = g_list_copy (gtk_application_get_windows (GTK_APPLICATION (shell)));
