@@ -83,6 +83,7 @@ struct _PrefsDialog {
   GtkWidget *popups_allow_checkbutton;
   GtkWidget *adblock_allow_checkbutton;
   GtkWidget *enable_plugins_checkbutton;
+  GtkWidget *enable_safe_browsing_checkbutton;
 
   /* fonts */
   GtkWidget *use_gnome_fonts_checkbutton;
@@ -506,6 +507,10 @@ sync_message_from_fxa_content_cb (WebKitUserContentManager *manager,
       goto out;
     }
 
+    if (!json_object_get_boolean_member (data, "verified"))
+      sync_sign_in_details_show (dialog, _("Please don’t leave this page until "
+                                           "you have completed the verification."));
+
     ephy_sync_service_sign_in (ephy_shell_get_sync_service (ephy_shell_get_default ()),
                                email, uid, session_token, key_fetch_token, unwrap_kb);
   }
@@ -582,7 +587,7 @@ on_sync_sign_out_button_clicked (GtkWidget   *button,
 {
   EphySyncService *service = ephy_shell_get_sync_service (ephy_shell_get_default ());
 
-  ephy_sync_service_sign_out (service);
+  ephy_sync_service_sign_out (service, TRUE);
 
   /* Show Firefox Accounts iframe. */
   sync_setup_firefox_iframe (dialog);
@@ -635,16 +640,10 @@ on_sync_device_name_save_button_clicked (GtkWidget   *button,
                                          PrefsDialog *dialog)
 {
   EphySyncService *service = ephy_shell_get_sync_service (ephy_shell_get_default ());
-  const char *text;
+  const char *name;
 
-  text = gtk_entry_get_text (GTK_ENTRY (dialog->sync_device_name_entry));
-  if (!g_strcmp0 (text, "")) {
-    char *name = ephy_sync_utils_get_device_name ();
-    gtk_entry_set_text (GTK_ENTRY (dialog->sync_device_name_entry), name);
-    g_free (name);
-  } else {
-    ephy_sync_service_update_device_name (service, text);
-  }
+  name = gtk_entry_get_text (GTK_ENTRY (dialog->sync_device_name_entry));
+  ephy_sync_service_register_device (service, name);
 
   gtk_widget_set_sensitive (GTK_WIDGET (dialog->sync_device_name_entry), FALSE);
   gtk_widget_set_visible (GTK_WIDGET (dialog->sync_device_name_change_button), TRUE);
@@ -736,6 +735,7 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, popups_allow_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, adblock_allow_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, enable_plugins_checkbutton);
+  gtk_widget_class_bind_template_child (widget_class, PrefsDialog, enable_safe_browsing_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, download_button_hbox);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, download_button_label);
 
@@ -800,44 +800,6 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, on_sync_device_name_cancel_button_clicked);
 }
 
-static void
-css_file_opened_cb (GObject      *source,
-                    GAsyncResult *result,
-                    gpointer      user_data)
-{
-  gboolean ret;
-  GError *error = NULL;
-
-  ret = ephy_open_file_via_flatpak_portal_finish (result, &error);
-  if (!ret) {
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-      g_warning ("Failed to open CSS file: %s", error->message);
-    g_error_free (error);
-  }
-}
-
-static void
-css_file_created_cb (GObject      *source,
-                     GAsyncResult *result,
-                     gpointer      user_data)
-{
-  GFile *file = G_FILE (source);
-  GFileOutputStream *stream;
-  GError *error = NULL;
-
-  stream = g_file_create_finish (file, result, &error);
-  if (stream == NULL && !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-    g_warning ("Failed to create %s: %s", g_file_get_path (file), error->message);
-  else
-    ephy_open_file_via_flatpak_portal (g_file_get_path (file), NULL, css_file_opened_cb, NULL);
-
-  if (error != NULL)
-    g_error_free (error);
-  if (stream != NULL)
-    g_object_unref (stream);
-  g_object_unref (file);
-}
-
 static void
 css_edit_button_clicked_cb (GtkWidget   *button,
                             PrefsDialog *pd)
@@ -848,13 +810,9 @@ css_edit_button_clicked_cb (GtkWidget   *button,
                                                     USER_STYLESHEET_FILENAME,
                                                     NULL));
 
-  if (ephy_is_running_inside_flatpak ()) {
-    g_file_create_async (css_file, G_FILE_CREATE_NONE, G_PRIORITY_DEFAULT, NULL, css_file_created_cb, NULL);
-  } else {
-    ephy_file_launch_handler ("text/plain", css_file,
-                              gtk_get_current_event_time ());
-    g_object_unref (css_file);
-  }
+  ephy_file_launch_handler ("text/plain", css_file,
+                            gtk_get_current_event_time ());
+  g_object_unref (css_file);
 }
 
 static void
@@ -864,7 +822,7 @@ language_editor_add (PrefsDialog *pd,
 {
   GtkTreeIter iter;
 
-  g_return_if_fail (code != NULL && desc != NULL);
+  g_assert (code != NULL && desc != NULL);
 
   if (gtk_tree_model_get_iter_first (pd->lang_model, &iter)) {
     do {
@@ -972,7 +930,7 @@ add_lang_dialog_response_cb (GtkWidget   *widget,
   GtkTreeIter iter;
   GList *rows, *r;
 
-  g_return_if_fail (dialog != NULL);
+  g_assert (dialog != NULL);
 
   if (response == GTK_RESPONSE_ACCEPT) {
     selection = gtk_tree_view_get_selection (pd->add_lang_treeview);
@@ -1018,7 +976,7 @@ get_name_for_lang_code (PrefsDialog *pd,
 
   str = g_strsplit (code, "-", -1);
   len = g_strv_length (str);
-  g_return_val_if_fail (len != 0, NULL);
+  g_assert (len != 0);
 
   langname = (const char *)g_hash_table_lookup (pd->iso_639_table, str[0]);
 
@@ -1418,16 +1376,21 @@ do_not_track_button_clicked_cb (GtkWidget   *button,
 {
   char **filters;
   char **new_filters;
+  char **newer_filters;
 
   filters = g_settings_get_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS);
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button))) {
     new_filters = ephy_strv_append ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-  else
+    newer_filters = ephy_strv_append ((const char * const *)new_filters, ADBLOCK_ANNOYANCE_FILTER_URL);
+  } else {
     new_filters = ephy_strv_remove ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)new_filters);
+    newer_filters = ephy_strv_remove ((const char * const *)new_filters, ADBLOCK_ANNOYANCE_FILTER_URL);
+  }
+  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)newer_filters);
 
   g_strfreev (filters);
   g_strfreev (new_filters);
+  g_strfreev (newer_filters);
 }
 
 static void
@@ -1726,6 +1689,11 @@ setup_general_page (PrefsDialog *dialog)
                    dialog->enable_plugins_checkbutton,
                    "active",
                    G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind (web_settings,
+                   EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING,
+                   dialog->enable_safe_browsing_checkbutton,
+                   "active",
+                   G_SETTINGS_BIND_DEFAULT);
 
   g_settings_bind (web_settings,
                    EPHY_PREFS_WEB_ENABLE_ADBLOCK,
