@@ -40,7 +40,6 @@
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
 #include "ephy-find-toolbar.h"
-#include "ephy-flatpak-utils.h"
 #include "ephy-gui.h"
 #include "ephy-header-bar.h"
 #include "ephy-history-dialog.h"
@@ -699,7 +698,7 @@ window_cmd_navigation (GSimpleAction *action,
   WebKitWebView *web_view;
 
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
 
@@ -722,7 +721,7 @@ window_cmd_navigation_new_tab (GSimpleAction *action,
   WebKitWebView *web_view;
 
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
 
@@ -775,7 +774,7 @@ window_cmd_stop (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   gtk_widget_grab_focus (GTK_WIDGET (embed));
 
@@ -816,7 +815,7 @@ window_cmd_reload (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   gtk_widget_grab_focus (GTK_WIDGET (embed));
 
@@ -1362,11 +1361,8 @@ window_cmd_save_as_application (GSimpleAction *action,
   char *markup;
   char *escaped_address;
 
-  if (ephy_is_running_inside_flatpak ())
-    return;
-
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   view = EPHY_WEB_VIEW (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
 
@@ -1503,7 +1499,7 @@ window_cmd_save_as (GSimpleAction *action,
   char *suggested_filename;
 
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   dialog = ephy_create_file_chooser (_("Save"),
                                      GTK_WIDGET (window),
@@ -1582,7 +1578,7 @@ window_cmd_cut (GSimpleAction *action,
   } else {
     EphyEmbed *embed;
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-    g_return_if_fail (embed != NULL);
+    g_assert (embed != NULL);
 
     webkit_web_view_execute_editing_command (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), WEBKIT_EDITING_COMMAND_CUT);
   }
@@ -1602,7 +1598,7 @@ window_cmd_copy (GSimpleAction *action,
     EphyEmbed *embed;
 
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-    g_return_if_fail (embed != NULL);
+    g_assert (embed != NULL);
 
     webkit_web_view_execute_editing_command (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), WEBKIT_EDITING_COMMAND_COPY);
   }
@@ -1622,7 +1618,7 @@ window_cmd_paste (GSimpleAction *action,
     EphyEmbed *embed;
 
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-    g_return_if_fail (embed != NULL);
+    g_assert (embed != NULL);
 
     webkit_web_view_execute_editing_command (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), WEBKIT_EDITING_COMMAND_PASTE);
   }
@@ -1642,7 +1638,7 @@ window_cmd_delete (GSimpleAction *action,
     EphyEmbed *embed;
 
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-    g_return_if_fail (embed != NULL);
+    g_assert (embed != NULL);
 
     /* FIXME: TODO */
 #if 0
@@ -1663,7 +1659,7 @@ window_cmd_print (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (EPHY_IS_EMBED (embed));
+  g_assert (EPHY_IS_EMBED (embed));
   view = ephy_embed_get_web_view (embed);
 
   ephy_web_view_print (view);
@@ -1799,55 +1795,6 @@ view_source_embedded (const char *uri, EphyEmbed *embed)
   gtk_widget_grab_focus (GTK_WIDGET (new_embed));
 }
 
-static void
-tmp_source_delete_cb (GObject *source, GAsyncResult *result, gpointer data)
-{
-  GFile *file = G_FILE (source);
-  GError *error = NULL;
-
-  if (!g_file_delete_finish (G_FILE (source), result, &error)) {
-    g_warning ("Failed to delete %s: %s", g_file_get_path (file), error->message);
-    g_error_free (error);
-  }
-
-  g_object_unref (file);
-}
-
-static void
-delete_tmp_source_file (GOutputStream *ostream)
-{
-  char *uri;
-  GFile *file;
-
-  g_object_get (G_OBJECT (ostream), "ephy-save-temp-source-uri", &uri, NULL);
-  file = g_file_new_for_uri (uri);
-  g_file_delete_async (file, G_PRIORITY_LOW, NULL, tmp_source_delete_cb, NULL);
-
-  g_free (uri);
-}
-
-static void
-portal_opened_cb (GObject *source, GAsyncResult *result, gpointer data)
-{
-  char *path = data;
-  GFile *file;
-  gboolean ret;
-  GError *error = NULL;
-
-  ret = ephy_open_file_via_flatpak_portal_finish (result, &error);
-  if (!ret) {
-    /* It can be canceled by the user, even without a cancellable. */
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-      g_warning ("Failed to open file via flatpak portal: %s", error->message);
-    g_error_free (error);
-  }
-
-  file = g_file_new_for_path (path);
-  g_free (path);
-
-  g_file_delete_async (file, G_PRIORITY_LOW, NULL, tmp_source_delete_cb, NULL);
-}
-
 static void
 save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointer data)
 {
@@ -1859,7 +1806,6 @@ save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointe
   if (error) {
     g_warning ("Unable to close file: %s", error->message);
     g_error_free (error);
-    delete_tmp_source_file (ostream);
     return;
   }
 
@@ -1867,14 +1813,6 @@ save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointe
 
   file = g_file_new_for_uri (uri);
 
-  if (ephy_is_running_inside_flatpak ()) {
-    const char *path;
-
-    path = g_file_get_path (file);
-    ephy_open_file_via_flatpak_portal (path, NULL, portal_opened_cb, g_strdup (path));
-    goto out;
-  }
-
   if (!ephy_file_launch_handler ("text/plain", file, gtk_get_current_event_time ())) {
     /* Fallback to view the source inside the browser */
     EphyEmbed *embed;
@@ -1885,9 +1823,8 @@ save_temp_source_close_cb (GOutputStream *ostream, GAsyncResult *result, gpointe
                                             "ephy-save-temp-source-embed");
     view_source_embedded (uri, embed);
   }
-
-out:
   g_object_unref (ostream);
+
   g_object_unref (file);
 }
 
@@ -1942,7 +1879,6 @@ get_main_resource_data_cb (WebKitWebResource *resource, GAsyncResult *result, GO
   if (error) {
     g_warning ("Unable to get main resource data: %s", error->message);
     g_error_free (error);
-    delete_tmp_source_file (ostream);
     return;
   }
 
@@ -2002,26 +1938,19 @@ save_temp_source (EphyEmbed *embed,
 {
   GFile *file;
   char *tmp, *base;
+  const char *static_temp_dir;
 
-  if (ephy_is_running_inside_flatpak ()) {
-    /* It has to go here because the portal has no access to our tmpfs.
-     * This means we have to delete it manually! */
-    base = g_build_filename (g_get_user_cache_dir (), "tmp", "viewsourceXXXXXX", NULL);
-  } else {
-    const char *static_temp_dir;
-
-    static_temp_dir = ephy_file_tmp_dir ();
-    if (static_temp_dir == NULL)
-      return;
-
-    base = g_build_filename (static_temp_dir, "viewsourceXXXXXX", NULL);
+  static_temp_dir = ephy_file_tmp_dir ();
+  if (static_temp_dir == NULL) {
+    return;
   }
 
+  base = g_build_filename (static_temp_dir, "viewsourceXXXXXX", NULL);
   tmp = ephy_file_tmp_filename (base, "html");
   g_free (base);
-
-  if (tmp == NULL)
+  if (tmp == NULL) {
     return;
+  }
 
   file = g_file_new_for_path (tmp);
   g_file_replace_async (file, NULL, FALSE,
@@ -2046,7 +1975,7 @@ window_cmd_page_source (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   address = ephy_web_view_get_address (ephy_embed_get_web_view (embed));
 
@@ -2086,7 +2015,7 @@ window_cmd_toggle_inspector (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   gtk_widget_grab_focus (GTK_WIDGET (embed));
 
@@ -2116,7 +2045,7 @@ window_cmd_select_all (GSimpleAction *action,
 
     embed = ephy_embed_container_get_active_child
               (EPHY_EMBED_CONTAINER (window));
-    g_return_if_fail (embed != NULL);
+    g_assert (embed != NULL);
 
     webkit_web_view_execute_editing_command (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), "SelectAll");
   }
@@ -2135,7 +2064,7 @@ window_cmd_send_to (GSimpleAction *action,
 
   embed = ephy_embed_container_get_active_child
             (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   location = ephy_web_view_get_address (ephy_embed_get_web_view (embed));
   title = ephy_embed_get_title (embed);
@@ -2241,7 +2170,7 @@ window_cmd_tabs_previous (GSimpleAction *action,
   GtkWidget *nb;
 
   nb = ephy_window_get_notebook (EPHY_WINDOW (user_data));
-  g_return_if_fail (nb != NULL);
+  g_assert (nb != NULL);
 
   ephy_notebook_prev_page (EPHY_NOTEBOOK (nb));
 }
@@ -2254,7 +2183,7 @@ window_cmd_tabs_next (GSimpleAction *action,
   GtkWidget *nb;
 
   nb = ephy_window_get_notebook (EPHY_WINDOW (user_data));
-  g_return_if_fail (nb != NULL);
+  g_assert (nb != NULL);
 
   ephy_notebook_next_page (EPHY_NOTEBOOK (nb));
 }
@@ -2371,7 +2300,7 @@ window_cmd_tabs_close (GSimpleAction *action,
   }
 
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  g_return_if_fail (embed != NULL);
+  g_assert (embed != NULL);
 
   g_signal_emit_by_name (notebook, "tab-close-request", embed);
 }
